@@ -1,9 +1,9 @@
 import os
 import pickle
 import re
+from sys import stdout
 import shutil
 from platform import uname
-from sys import stdout
 from tempfile import mkdtemp
 
 import mdtraj
@@ -15,6 +15,112 @@ from .utils import *
 
 
 class MDSimulation():
+    """Base Simulation Class for MDSimulations.
+
+    Examples
+    --------
+
+    Load packages
+    >>> import parmed
+    >>> from simtk.openmm import unit
+    >>> from ommtk import MDSimulation, select_atoms
+
+    instantiate sim from parmed alone, minimize (save h5 file) and run
+    >>> mdsim = MDSimulation(parmed_structure=parmed)
+    >>> mdsim.minimize()
+    >>> minimized_parmed = mdsim.run(2 * unit.nanosecond)
+
+    build sim using a previous trajectory or h5 file
+    >>> mdsim = MDSimulation(parmed_structure=parmed_structure, coordinates=trajectory.h5)
+
+    build sim with positional restraints, run some equilibration and remove them for longer run
+    >>> protein_atoms = select_atoms(parmed_structure=parmed_structure, keyword_selection='protein')
+    >>> mdsim = MDSimulation(parmed_structure=parmed_structure, atoms_to_restrain=protein_atoms, restraint_weight=4)
+    >>> mdsim.run(1*unit.nanosecond)
+    >>> mdsim.update_restraint_weight(2)
+    >>> mdsim.run(1*unit.nanosecond)
+    >>> mdsim.remove_positional_restraints()
+    >>> end_parmed = mdsim.run(4 * unit.nanosecond)
+
+    Parameters
+    ----------
+    parmed_structure : Parmed.Structure
+        The Parmed Topology Object containing topology nand force field parameters
+
+    coordinates: unit.Quantity or mdtraj.Trajectory, optional
+        Alternate coordiantes to be used if parmed_structure coordinates aren't going to be used
+
+    velocities: numpy array, optional
+        Velociites to be used for restarting sim from previous simulation
+
+    box_vectors: unit.Quantity, optional
+        Box vectors to be used for simulation. If not specified box vectors are taken from parmed_structure
+
+    cwd : string, optional
+        directory for storing simulation files. If None a folder will be created in /tmp/ with a unique 6 digit randomized name
+
+    temperature: unit.Quantity, optional
+        temperature for running simulation and Langevin bath if used. Default 300 Kelvin
+
+    pressue : unit.Quantity, optional
+        pressure at which to hold the simulation via barostat. If None no temperature control will be used
+
+    membrane : bool, optional
+        flag for whether or not the simulation contains a membrane, which will ensure the correct barostat is used for membranes
+
+    integrator_type : {'Langevin, Verlet'}, optional
+        string indicating integrator type to use. Default: Langevin
+
+    platform_name : {'Reference, CPU, CUDA, OpenCL'}, optional
+        string indicating which platform to use for running simulation. If None the fastest platform available will be used
+
+    nonbonded_method : string, optional
+        string indicating nonbonded method to use, default is PME
+
+    nonbonded_cutoff : unit.Quantity, optional
+        nonbonded cutoff distance, default 1 *unit.nanometer
+
+    atoms_to_freeze : list of integers, optional
+        list of atom indeces indicating which atoms to freeze during the simulation
+
+    atoms_to_restrain : list of integers, optional
+        list of atoms indeces to restrain to initial positions during the simulation
+
+    restraint_weight : unit.Quantity or float, optional
+        force constant to be used for positional restraints. If not units given, they will be assumed as kcal/mol/A.
+
+    constraints :  {'HBonds', 'HAngles' ,'AllBonds'}, optional
+        type of constraints to use during simulation. Default is HBonds
+
+    implicit_solvent_model : {'HCT', 'OBC1', 'OBC2', 'GBn', 'GBn2'}, optional
+        string indicating the type of implicit model to use if any
+
+    hmr : boolean, optional
+        boolean indicating whether or not to use Hydrogen Mass Repartitioning and a 4 fs time step.
+
+    run_time : unit.Quantity, optional
+        default run time for the simulation if non is given as input to run method.
+
+    state_interval : unit.Quantity, optional
+        interval with which to write state information (temperature, potential energy etc) to file
+
+    state_out :  string, optional
+        name of file for writing state information. Defaults to 'sim.log'
+
+    progress_interval : unit.Quantity, optional
+        Frequency with which to report progress data
+
+    progress_out : string or sys.stdout, optional
+        name of file for writing progress information. Defaults to 'progress.log' If sys.stdout is specified,
+        pickling of the simulation will not be supported
+
+    traj_interval : unit.Quantity, optional
+        frequency to write trajectory information to file
+
+    traj_out : string, optional
+        name of file for writing trajectory information. Defaults to 'trajectory.h5'
+
+    """
     def __init__(self, parmed_structure, coordinates=None,
                  velocities=None, box_vectors=None,
                  cwd=None, centering=False,
@@ -32,112 +138,6 @@ class MDSimulation():
                  run_time = 2 * unit.nanosecond
                  ):
 
-        """Base Simulation Class for MDSimulations.
-
-        Examples
-        --------
-
-        Load packages
-        >>> import parmed
-        >>> from simtk.openmm import unit
-        >>> from ommtk import MDSimulation, select_atoms
-
-        instantiate sim from parmed alone, minimize (save h5 file) and run
-        >>> mdsim = MDSimulation(parmed_structure=parmed)
-        >>> mdsim.minimize()
-        >>> minimized_parmed = mdsim.run(2 * unit.nanosecond)
-
-        build sim using a previous trajectory or h5 file
-        >>> mdsim = MDSimulation(parmed_structure=parmed_structure, coordinates=trajectory.h5)
-
-        build sim with positional restraints, run some equilibration and remove them for longer run
-        >>> protein_atoms = select_atoms(parmed_structure=parmed_structure, keyword_selection='protein')
-        >>> mdsim = MDSimulation(parmed_structure=parmed_structure, atoms_to_restrain=protein_atoms, restraint_weight=4)
-        >>> mdsim.run(1*unit.nanosecond)
-        >>> mdsim.update_restraint_weight(2)
-        >>> mdsim.run(1*unit.nanosecond)
-        >>> mdsim.remove_positional_restraints()
-        >>> end_parmed = mdsim.run(4 * unit.nanosecond)
-
-        Parameters
-        ----------
-        parmed_structure : Parmed.Structure
-            The Parmed Topology Object containing topology nand force field parameters
-
-        coordinates: unit.Quantity or mdtraj.Trajectory, optional
-            Alternate coordiantes to be used if parmed_structure coordinates aren't going to be used
-
-        velocities: numpy array, optional
-            Velociites to be used for restarting sim from previous simulation
-
-        box_vectors: unit.Quantity, optional
-            Box vectors to be used for simulation. If not specified box vectors are taken from parmed_structure
-
-        cwd : string, optional
-            directory for storing simulation files. If None a folder will be created in /tmp/ with a unique 6 digit randomized name
-
-        temperature: unit.Quantity, optional
-            temperature for running simulation and Langevin bath if used. Default 300 Kelvin
-
-        pressue : unit.Quantity, optional
-            pressure at which to hold the simulation via barostat. If None no temperature control will be used
-
-        membrane : bool, optional
-            flag for whether or not the simulation contains a membrane, which will ensure the correct barostat is used for membranes
-
-        integrator_type : {'Langevin, Verlet'}, optional
-            string indicating integrator type to use. Default: Langevin
-
-        platform_name : {'Reference, CPU, CUDA, OpenCL'}, optional
-            string indicating which platform to use for running simulation. If None the fastest platform available will be used
-
-        nonbonded_method : string, optional
-            string indicating nonbonded method to use, default is PME
-
-        nonbonded_cutoff : unit.Quantity, optional
-            nonbonded cutoff distance, default 1 *unit.nanometer
-
-        atoms_to_freeze : list of integers, optional
-            list of atom indeces indicating which atoms to freeze during the simulation
-
-        atoms_to_restrain : list of integers, optional
-            list of atoms indeces to restrain to initial positions during the simulation
-
-        restraint_weight : unit.Quantity or float, optional
-            force constant to be used for positional restraints. If not units given, they will be assumed as kcal/mol/A.
-
-        constraints :  {'HBonds', 'HAngles' ,'AllBonds'}, optional
-            type of constraints to use during simulation. Default is HBonds
-
-        implicit_solvent_model : {'HCT', 'OBC1', 'OBC2', 'GBn', 'GBn2'}, optional
-            string indicating the type of implicit model to use if any
-
-        hmr : boolean, optional
-            boolean indicating whether or not to use Hydrogen Mass Repartitioning and a 4 fs time step.
-
-        run_time : unit.Quantity, optional
-            default run time for the simulation if non is given as input to run method.
-
-        state_interval : unit.Quantity, optional
-            interval with which to write state information (temperature, potential energy etc) to file
-
-        state_out :  string, optional
-            name of file for writing state information. Defaults to 'sim.log'
-
-        progress_interval : unit.Quantity, optional
-            Frequency with which to report progress data
-
-        progress_out : string or sys.stdout, optional
-            name of file for writing progress information. Defaults to 'progress.log' If sys.stdout is specified,
-            pickling of the simulation will not be supported
-
-        traj_interval : unit.Quantity, optional
-            frequency to write trajectory information to file
-
-        traj_out : string, optional
-            name of file for writing trajectory information. Defaults to 'trajectory.h5'
-
-        """
         self.parmed_structure = parmed_structure
 
         # check that the coordinates have units
@@ -463,6 +463,12 @@ class MDSimulation():
         else:
             print('storing sim files in directory {}'.format(self.cwd))
 
+        if self.state_out=='stdout':
+            self.state_out = stdout
+
+        if self.progress_out=='stdout':
+            self.progress_out = stdout
+
         if self.centering:
             self.center_coordinates()
 
@@ -583,11 +589,7 @@ class MDSimulation():
 
     def pickle_sim(self, pickle_name='mdsim.pickle'):
         """ Remove the Swigpy objects that don't pickle and write the current simulation pickle to cwd
-        In order to use the pickle you will need to run _build_sim and _build_custom_forces
-
-        pickle_name string
-            name of file to write pickle to. cwd is appended to the prefix.
-
+        In order to use the pickle you will need to run _build_sim
         Examples
         -------
         >>> mdsim.pickle_sim()
@@ -595,24 +597,35 @@ class MDSimulation():
         >>>     new_sim = pickle.load(handle)
         >>>
         >>> new_sim._build_sim()
+        >>> new_sim._build_custom_forces()
         >>> new_sim.run()
-
-
         """
 
-        if (self.progress_out == stdout) or (self.state_out == stdout):
-            raise ValueError('cant pickle system if any logs point to stdout!')
+        # if (self.progress_out == stdout) or (self.state_out == stdout):
+        #     raise ValueError('cant pickle system if any logs point to stdout!')
 
         print('removing sim and system objects in order to pickle')
         del self.simulation
         del self.system
         del self.platform
+        try:
+            del self.metaD
+        except AttributeError:
+            pass
+        try:
+            del self.ser_temp
+        except AttributeError:
+            pass
+
+        if not isinstance(self.progress_out,str):
+            self.progress_out = "stdout"
 
         fname = os.path.join(self.cwd, pickle_name)
         with open(fname, 'wb') as handle:
             pickle.dump(obj=self, file=handle)
         print('pickled sim saved as {}'.format(fname))
-        # print('to use it once unpickled you will need to run self._build_sim()')
+        print('to use it once unpickled you will need to run self._build_sim() and self._build_custom_forces()')
+
 
     def purge_sim_files(self):
         """Removes all files in mdsim.cwd
@@ -1286,36 +1299,6 @@ class MetadynamicSimulation(MDSimulation):
         self.simulation.context.setPositions(self.positions)
 
 
-    def pickle_sim(self, pickle_name='mdsim.pickle'):
-        """ Remove the Swigpy objects that don't pickle and write the current simulation pickle to cwd
-        In order to use the pickle you will need to run _build_sim
-
-        Examples
-        -------
-        >>> mdsim.pickle_sim()
-        >>> with open(os.path.join(mdsim.cwd,'mdsim.pickle'), 'rb') as handle:
-        >>>     new_sim = pickle.load(handle)
-        >>>
-        >>> new_sim._build_sim()
-        >>> new_sim._build_custom_forces()
-        >>> new_sim.run()
-        """
-
-        if (self.progress_out == stdout) or (self.state_out == stdout):
-            raise ValueError('cant pickle system if any logs point to stdout!')
-
-        print('removing sim and system objects in order to pickle')
-        del self.simulation
-        del self.system
-        del self.platform
-        del self.metaD
-
-        fname = os.path.join(self.cwd, pickle_name)
-        with open(fname, 'wb') as handle:
-            pickle.dump(obj=self, file=handle)
-        print('pickled sim saved as {}'.format(fname))
-        print('to use it once unpickled you will need to run self._build_sim() and self._build_custom_forces()')
-
     def _add_FESReporter(self):
         """
         adds the FES reporter to the sim
@@ -1382,6 +1365,10 @@ class SimulatedTemperingSimulation(MDSimulation):
         self.reportInterval = reportInterval
         self.reportFile = os.path.join(self.cwd, reportFile)
 
+        self._build_custom_forces()
+
+
+    def _build_custom_forces(self):
         self.ser_temp = mm.app.SimulatedTempering(self.simulation,
                                                   numTemperatures=self.numTemperatures,
                                                   minTemperature=self.minTemperature,
